function [Calculated_age,Th_232_neon_prod,U_238_neon_prod,U_235_neon_prod] = alpha_fluence(Th_232_yields,U_238_yields,U_235_yields,U_ppm,Th_ppm,Ne_pcc,~,~)


%% User inputs

Th_ppm;                   % Th content (ppm)
U_ppm;                    % U content (ppm)
Ne_pcc;                   % Ne content (pcc STP)
mass_of_material = 1;     % mass of material (g)

%% Defined and calculated values

Th_mass = Th_ppm*10^-6*mass_of_material;            % Th content (g)
U_mass = U_ppm*10^-6*mass_of_material;              % U content (g)
 
Na = 6.02214129e23;                                 % Avogadro constant
Th_232_atoms = (Th_mass/232.0380553)*Na;            % Atoms of thorium-232
U_238_atoms = ((U_mass*0.992742)/238.0507882)*Na;   % Atoms of uranium-238
U_235_atoms = ((U_mass*0.007204)/235.0439299)*Na;   % Atoms of uranium-235
Ne_atoms = ((Ne_pcc*10^-15)/22.414)*Na;             % Atoms of neon

Th_232_lambda = log(2)/1.405e10;                    % Half-life of thorium-232
U_238_lambda = log(2)/4.468e9;                      % Half-life of uranium-238
U_235_lambda = log(2)/7.04e8;                       % Half-life of uranium-235

%% Create alpha production matrix

t = logspace(0,9.69897,1000);                           % log-spaced time vector back to five billion years

Th_232_decays = Th_232_atoms*(exp(Th_232_lambda*t)-1);  % decays through time from thorium-232
U_238_decays = U_238_atoms*(exp(U_238_lambda*t)-1);     % decays through time from uranium-238
U_235_decays = U_235_atoms*(exp(U_235_lambda*t)-1);     % decays through time from uranium-235

% set(0,'defaultaxesposition',[0.1 0.1 0.8 0.8])
% figure(3)
% plot(t,Th_232_decays,t,U_238_decays,t,U_235_decays)
% title('Alpha production from each isotope if sample is a given age')
% legend('Thorium-232','Uranium-238','Uranium-235')

%% Compute neon production rates

Th_232_alpha_production_rates = Th_232_yields; % Production rate of each alpha from thorium-232 decay in the material of interest
U_238_alpha_production_rates = U_238_yields;   % Production rate of each alpha from uranium-238 decay in the material of interest
U_235_alpha_production_rates = U_235_yields;   % Production rate of each alpha from uranium-235 decay in the material of interest

Th_232_neon = sum(Th_232_decays'*Th_232_alpha_production_rates,2);                  % Production of neon from thorium-232 alphas
U_238_neon = sum(U_238_decays'*U_238_alpha_production_rates,2);                     % Production of neon from uranium-238 alphas
U_235_neon = sum(U_235_decays'*U_235_alpha_production_rates,2);                     % Production of neon from uranium-235 alphas
Total_neon = Th_232_neon + U_238_neon + U_235_neon;                                 % Production of neon from all alphas
Measured_neon = ones(length(t),1)*Ne_atoms;                                         % Dummy vector of measured neon in length t for plotting

% figure(4)
% plot(t,Th_232_neon,t,U_238_neon,t,U_235_neon,t,Total_neon,t,Measured_neon)
% title('Neon production from each isotope if sample is a given age')
% legend('Thorium-232','Uranium-238','Uranium-235','Total','Measured')

%% Compute neon/helium ratio

Th_232_alphas = Th_232_decays'*6;
U_238_alphas = U_238_decays'*8;
U_235_alphas = U_235_decays'*7;
Total_alphas = Th_232_alphas + U_238_alphas + U_235_alphas;

Th_232_Ratio = Th_232_neon./Th_232_alphas;
U_238_Ratio = U_238_neon./U_238_alphas;
U_235_Ratio = U_235_neon./U_235_alphas;
Ratio = Total_neon./Total_alphas;

% figure(5)
% plot(t,Th_232_Ratio,t,U_238_Ratio,t,U_235_Ratio,t,Ratio)
% title('Neon to helium-4 production ratio in sample of a given age')
% legend('Thorium-232','Uranium-238','Uranium-235','Total')

%% Find the age
[trash ind] = min(abs(Measured_neon-Total_neon));
Calculated_neon = Total_neon(ind);
Calculated_age = t(ind);

error_range = (t(ind+1)-t(ind-1));
t_fine_scale = linspace(t(ind-1),t(ind+1),1000);

while error_range > 1000

    Th_232_decays = Th_232_atoms*(exp(Th_232_lambda*t_fine_scale)-1);   % decays through time from thorium-232
    U_238_decays = U_238_atoms*(exp(U_238_lambda*t_fine_scale)-1);      % decays through time from uranium-238
    U_235_decays = U_235_atoms*(exp(U_235_lambda*t_fine_scale)-1);      % decays through time from uranium-235

    Th_232_neon = sum(Th_232_decays'*Th_232_alpha_production_rates,2);  % Production of neon from thorium-232 alphas
    U_238_neon = sum(U_238_decays'*U_238_alpha_production_rates,2);     % Production of neon from uranium-238 alphas
    U_235_neon = sum(U_235_decays'*U_235_alpha_production_rates,2);     % Production of neon from uranium-235 alphas
    Total_neon = Th_232_neon + U_238_neon + U_235_neon;                 % Production of neon from all alphas

    [~,ind] = min(abs(Measured_neon-Total_neon));
    Calculated_neon = Total_neon(ind);
    Calculated_age = t_fine_scale(ind);

    t_fine_scale = linspace(t_fine_scale(ind-1),t_fine_scale(ind+1),1000);
    error_range = (t_fine_scale(ind+1)-t_fine_scale(ind-1));

end

Th_232_neon_prod = 1000*22.414/6.022e23*Th_232_Ratio(1)*6;
U_238_neon_prod = 1000*22.414/6.022e23*U_238_Ratio(1)*8;
U_235_neon_prod = 1000*22.414/6.022e23*U_235_Ratio(1)*7;
Calculated_age = t_fine_scale(ind);
